The function implements a stationarity test procedure, where the main statistic is obtained from measuring the difference in the second-order structure over pairs of randomly drawn intervals. Maximising the main statistics after AR Sieve bootstrap-based variance stabilisation, the test statistic is obtained which is reported along with the corresponding pair of intervals and the test outcome.
unsys.station.test(
x,
M = 2000,
sig.lev = 0.05,
max.scale = NULL,
m = NULL,
B = 200,
eps = 5,
use.all = FALSE,
do.parallel = 0
)a pair of intervals corresponding to the test statistic, exhibiting the most distinct second-order behaviour
test statistic
test criterion
if test.res=TRUE, the null hypothesis of stationarity is rejected at the given significance level
input time series
number of randomly drawn intervals
significance level between 0 and 1
number of wavelet scales used for wavelet periodogram computation; max.scale = NULL activates the default choice (max.scale = round(log(log(length(x), 2), 2)))
minimum length of a random interval; m = NULL activates the default choice (m = round(sqrt(length(x))))
bootstrap sample size
a parameter used for random interval generation, see the supplementary document of Cho (2016)
if use.all=TRUE, all M*M pairs of random intervals are considered in test statistic computation; if use.all=FALSE, only 10*M pairs are used; regardless, the whole M*M pairs are considered in test criterion generation
number of copies of R running in parallel, if do.parallel = 0, %do% operator is used, see also foreach
H. Cho (2016) A second-order stationarity of time series based on unsystematic sub-samples. Stat, vol. 5, 262-277.
if (FALSE) {
x <- rnorm(200)
unsys.station.test(x, M=1000)
}
Run the code above in your browser using DataLab